"""

:Author: Franziska Koehn
:Created: 2015/01/13

This module contains the MenuView (a ToolBar).

"""

import gtk
import gobject

class MenuView(gtk.Toolbar):
    """A ToolBar containing Buttons"""

    def disable_export_button(self, is_enable, text):
        """Disables export-button and sets given text as tooltip.

        **Parameters**
            :is_enable: bool: true for enabling and false for disabling export-button
            :text: str, that will be set as tooltip
        """
        self.tb_export.set_tooltip_text(text)
        self.tb_export.set_sensitive(is_enable)

    def disable_download_button(self, is_enable, text):
        """Disables download-button and sets given text as tooltip.

        **Parameters**
            :is_enable: bool: true for enabling and false for disabling download-button
            :text: str, that will be set as tooltip
        """
        self.tb_downl.set_tooltip_text(text)
        self.tb_downl.set_sensitive(is_enable)

    def disable_adddata_button(self, is_enable, text):
        """Disables get-additional-data-button and sets given text as tooltip.

        **Parameters**
            :is_enable: bool: true for enabling and false for disabling button
            :text: str, that will be set as tooltip
        """
        self.tb_adddata.set_tooltip_text(text)
        self.tb_adddata.set_sensitive(is_enable)

    def __init__(self, *args, **kwargs):
        """Creates buttons for this Toolbar and defines signals when this buttons will be pressed.

        **Parameters**

            :\*args: arguments passed to gtk.Toolbar-constructor
            :\*\*kwargs: keyword-arguments passed to gtk.Toolbar-constructor
        """
        super(MenuView, self).__init__(*args, **kwargs)

        self.set_orientation(gtk.ORIENTATION_HORIZONTAL)
        self.set_style(gtk.TOOLBAR_BOTH)

        gobject.signal_new( "spawn-connection-dialog",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "get-additional-data",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "send-query",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "toggle-selection",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "download-selection",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "save-query",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new( "load-query",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())
        gobject.signal_new("export-csv",
                            MenuView,
                            gobject.SIGNAL_RUN_FIRST,
                            gobject.TYPE_NONE,
                            ())

        tb_savequery = gtk.ToolButton()
        tb_savequery.set_label("Save Query")
        tb_savequery.set_tooltip_text("Save Query")
        tb_savequery.set_stock_id(gtk.STOCK_FLOPPY)
        tb_savequery.connect("clicked",lambda *_: self.emit("save-query"))
        self.insert(tb_savequery, 0)

        tb_loadquery = gtk.ToolButton()
        tb_loadquery.set_label("Load Query")
        tb_loadquery.set_tooltip_text("Load Query")
        tb_loadquery.set_stock_id(gtk.STOCK_DIRECTORY)
        tb_loadquery.connect("clicked",lambda *_: self.emit("load-query"))
        self.insert(tb_loadquery, 1)

        tb_servset = gtk.ToolButton()
        tb_servset.set_label("Server Settings")
        tb_servset.set_tooltip_text("Alter host, user-name and password")
        tb_servset.set_stock_id(gtk.STOCK_DIALOG_AUTHENTICATION)
        tb_servset.connect("clicked",lambda *_: self.emit("spawn-connection-dialog"))
        self.insert(tb_servset, 2)

        tb_sendquery = gtk.ToolButton()
        tb_sendquery.set_label("Send Query")
        tb_sendquery.set_tooltip_text("Send Query")
        tb_sendquery.set_stock_id(gtk.STOCK_YES)
        tb_sendquery.connect("clicked",lambda *_: self.emit("send-query"))
        self.insert(tb_sendquery, 3)

        self.insert(gtk.SeparatorToolItem(), 4)

        tb_toggsel = gtk.ToolButton()
        tb_toggsel.set_label("Toggle Selection")
        tb_toggsel.set_tooltip_text("Toggle selection of result-table")
        tb_toggsel.set_stock_id(gtk.STOCK_SELECT_ALL)
        tb_toggsel.connect("clicked",lambda *_: self.emit("toggle-selection"))
        self.insert(tb_toggsel, 5)

        self.tb_downl = gtk.ToolButton()
        self.tb_downl.set_label("Download Selected Items")
        self.tb_downl.set_stock_id(gtk.STOCK_SAVE)
        self.tb_downl.connect("clicked",lambda *_: self.emit("download-selection"))
        self.insert(self.tb_downl, 6)

        self.tb_export = gtk.ToolButton()
        self.tb_export.set_label("Export As CSV")
        self.tb_export.set_stock_id(gtk.STOCK_CONVERT)
        self.tb_export.connect("clicked",lambda *_: self.emit("export-csv"))
        self.insert(self.tb_export, 7)

        self.insert(gtk.SeparatorToolItem(), 8)

        self.tb_adddata = gtk.ToolButton()
        self.tb_adddata.set_label("Get Additional Data")
        self.tb_adddata.set_stock_id(gtk.STOCK_INDEX)
        self.tb_adddata.connect("clicked",lambda *_: self.emit("get-additional-data"))
        self.insert(self.tb_adddata, 9)



        self.disable_download_button(False, "No Results")
        self.disable_adddata_button(False, "No Results")
        self.disable_export_button(False, "No Results")
